@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 1;
 
@@ -47,12 +47,18 @@ Print error as simple string over HTTP.
 
 L<Error::Pure>,
 L<Error::Pure::AllError>,
+L<Error::Pure::Always>,
 L<Error::Pure::Die>,
 L<Error::Pure::Error>,
 L<Error::Pure::ErrorList>,
+L<Error::Pure::HTTP::AllError>,
 L<Error::Pure::HTTP::Error>,
 L<Error::Pure::HTTP::ErrorList>,
+L<Error::Pure::HTTP::JSON>,
 L<Error::Pure::HTTP::Print>,
+L<Error::Pure::JSON>,
+L<Error::Pure::NoDie>,
+L<Error::Pure::Output::JSON>,
 L<Error::Pure::Output::Text>,
 L<Error::Pure::Print>,
 L<Error::Pure::Utils>.
@@ -73,6 +79,6 @@ BSD license.
 
 =head1 VERSION
 
-0.11
+0.12
 
 =cut
