@@ -16,7 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -133,12 +133,17 @@ L<Readonly>.
 
 L<Error::Pure>,
 L<Error::Pure::AllError>,
+L<Error::Pure::Always>,
 L<Error::Pure::Die>,
 L<Error::Pure::Error>,
 L<Error::Pure::ErrorList>,
 L<Error::Pure::HTTP::Error>,
 L<Error::Pure::HTTP::ErrorList>,
+L<Error::Pure::HTTP::JSON>,
 L<Error::Pure::HTTP::Print>,
+L<Error::Pure::JSON>,
+L<Error::Pure::NoDie>,
+L<Error::Pure::Output::JSON>,
 L<Error::Pure::Output::Text>,
 L<Error::Pure::Print>,
 L<Error::Pure::Utils>.
@@ -159,6 +164,6 @@ BSD license.
 
 =head1 VERSION
 
-0.11
+0.12
 
 =cut
